Discover Packages
bitbucket.org/ignitionrobotics/ign-fuelserver
bundles
generics
package
Version:
v0.0.0-...-4436486
Opens a new window with list of versions in this module.
Published: Jan 17, 2020
License: Apache-2.0
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
SendEmail sends a generic email from HTML template
SendReportEmail sends an alert to admins about a resource report
type Report struct {
gorm .Model
Reason *string `gorm:"type:text" json:"reason,omitempty"`
}
Report represents a generic resource report
Source Files
¶
Click to show internal directories.
Click to hide internal directories.